@@ -28,11 +28,15 @@ from PyQt5.QtCore import (
 )
 
 import platform
-
-if platform.system() == 'Darwin':
-    from PyQt5.QtWebEngineWidgets import QWebEngineView as QWebView
-elif platform.system() == 'Linux':
-    from PyQt5.QtWebKitWidgets import QWebView
+try:
+    if platform.system() == 'Darwin' or platform.system() == 'Windows':
+        from PyQt5.QtWebEngineWidgets import QWebEngineView as QWebView
+    elif platform.system() == 'Linux':
+        from PyQt5.QtWebKitWidgets import QWebView
+    USE_WEB_KIT = True
+except ImportError:
+    QWebView = None
+    USE_WEB_KIT = False
 
 from PyQt5.QtCore import pyqtProperty as Property, pyqtSignal as Signal, \
                          pyqtSlot as Slot
@@ -381,10 +385,13 @@ class CanvasMainWindow(QMainWindow):
                                         objectName="help-dock")
         self.help_dock.setAllowedAreas(Qt.NoDockWidgetArea)
 
-        self.help_view = QWebView()
+        if USE_WEB_KIT:
+            self.help_view = QWebView()
 
-        self.help_dock.setWidget(self.help_view)
-        self.help_dock.hide()
+            self.help_dock.setWidget(self.help_view)
+            self.help_dock.hide()
+        else:
+            self.help_view = None
 
         self.setMinimumSize(600, 500)
 
@@ -458,19 +465,28 @@ class CanvasMainWindow(QMainWindow):
                     icon=canvas_icons("Get Started.svg")
                     )
 
+        def oasys_school():
+            import webbrowser
+            webbrowser.open("https://github.com/oasys-kit/oasys_school")
+
         self.tutorials_action = \
-            QAction(self.tr("Tutorials"), self,
+            QAction(self.tr("OASYS School"), self,
                     objectName="tutorial-action",
                     toolTip=self.tr("Browse tutorials."),
-                    triggered=self.tutorial_scheme,
+                    triggered=oasys_school,
                     icon=canvas_icons("Tutorials.svg")
                     )
 
+        def web_site():
+            import webbrowser
+            webbrowser.open("https://www.aps.anl.gov/Science/Scientific-Software/OASYS")
+
+
         self.documentation_action = \
-            QAction(self.tr("Documentation"), self,
+            QAction(self.tr("Web Site"), self,
                     objectName="documentation-action",
                     toolTip=self.tr("View reference documentation."),
-                    triggered=self.documentation,
+                    triggered=web_site,
                     icon=canvas_icons("Documentation.svg")
                     )
 
@@ -484,9 +500,10 @@ class CanvasMainWindow(QMainWindow):
 
         # Action group for for recent scheme actions
         self.recent_scheme_action_group = \
-            QActionGroup(self, exclusive=False,
+            QActionGroup(self,
                          objectName="recent-action-group",
                          triggered=self._on_recent_scheme_action)
+        self.recent_scheme_action_group.setExclusive(True) # upgrade to PyQt5 5.14
 
         self.recent_action = \
             QAction(self.tr("Browse Recent"), self,
@@ -1356,9 +1373,9 @@ class CanvasMainWindow(QMainWindow):
             if self.recent_scheme() == QDialog.Accepted:
                 dialog.accept()
 
-        def tutorial():
-            if self.tutorial_scheme() == QDialog.Accepted:
-                dialog.accept()
+        def oasys_school():
+            import webbrowser
+            webbrowser.open("https://github.com/oasys-kit/oasys_school")
 
         new_action = \
             QAction(self.tr("New"), dialog,
@@ -1388,10 +1405,10 @@ class CanvasMainWindow(QMainWindow):
                     )
 
         tutorials_action = \
-            QAction(self.tr("Tutorial"), dialog,
+            QAction(self.tr("OASYS School"), dialog,
                     objectName="welcome-tutorial-action",
                     toolTip=self.tr("Browse tutorial workflows."),
-                    triggered=tutorial,
+                    triggered=oasys_school,
                     icon=canvas_icons("Tutorials.svg")
                     )
 
@@ -1848,9 +1865,13 @@ class CanvasMainWindow(QMainWindow):
                 url = QUrl(url.toString())
                 QDesktopServices.openUrl(url)
         else:
-            self.help_view.load(QUrl(url))
-            self.help_dock.show()
-            self.help_dock.raise_()
+            if USE_WEB_KIT:
+                self.help_view.load(QUrl(url))
+
+                self.help_dock.show()
+                self.help_dock.raise_()
+            else:
+                pass
 
     # Mac OS X
     if sys.platform == "darwin":
