@@ -20,7 +20,7 @@ from PyQt5.QtGui import (
     QPainterPath, QPainterPathStroker
 )
 
-from PyQt5.QtCore import Qt, QPointF, QRectF, QSize, QTimer, QPropertyAnimation
+from PyQt5.QtCore import Qt, QPointF, QRect, QRectF, QSize, QTimer, QPropertyAnimation
 from PyQt5.QtCore import pyqtSignal as Signal
 from PyQt5.QtCore import pyqtProperty as Property
 
@@ -684,35 +684,13 @@ class GraphicsIconItem(QGraphicsItem):
             else:
                 mode = QIcon.Disabled
 
-            transform = self.sceneTransform()
-
-            if widget is not None:
-                # 'widget' is the QGraphicsView.viewport()
-                view = widget.parent()
-                if isinstance(view, QGraphicsView):
-                    # Combine the scene transform with the view transform.
-                    view_transform = view.transform()
-                    transform = view_transform * view_transform
-
-            lod = option.levelOfDetailFromTransform(transform)
-
             w, h = self.__iconSize.width(), self.__iconSize.height()
-            target = QRectF(0, 0, w, h)
-            source = QRectF(0, 0, w * lod, w * lod).toRect()
-
-            # The actual size of the requested pixmap can be smaller.
-            size = self.__icon.actualSize(source.size(), mode=mode)
-            source.setSize(size)
-
-            pixmap = self.__icon.pixmap(source.size(), mode=mode)
-
+            target = QRect(0, 0, w, h)
             painter.setRenderHint(
                 QPainter.SmoothPixmapTransform,
                 self.__transformationMode == Qt.SmoothTransformation
             )
-
-            painter.drawPixmap(target, pixmap, QRectF(source))
-
+            self.__icon.paint(painter, target, Qt.AlignCenter, mode)
 
 class NameTextItem(QGraphicsTextItem):
     def __init__(self, *args, **kwargs):
