@@ -39,7 +39,7 @@ from PyQt5.QtGui import (
 )
 
 from PyQt5.QtCore import (
-    Qt, QObject, QEvent, QSignalMapper, QRectF, QCoreApplication
+    Qt, QObject, QEvent, QSignalMapper, QRectF, QCoreApplication, QSettings
 )
 
 from PyQt5.QtCore import pyqtProperty as Property, pyqtSignal as Signal
@@ -222,8 +222,9 @@ class SchemeEditWidget(QWidget):
         # Create a font size menu for the new annotation action.
         self.__fontMenu = QMenu("Font Size", self)
         self.__fontActionGroup = group = \
-            QActionGroup(self, exclusive=True,
+            QActionGroup(self,
                          triggered=self.__onFontSizeTriggered)
+        self.__fontActionGroup.setExclusive(True) # upgrade to PyQt5 5.14
 
         def font(size):
             f = QFont(self.font())
@@ -252,8 +253,9 @@ class SchemeEditWidget(QWidget):
         # Create a color menu for the arrow annotation action
         self.__arrowColorMenu = QMenu("Arrow Color",)
         self.__arrowColorActionGroup = group = \
-            QActionGroup(self, exclusive=True,
+            QActionGroup(self,
                          triggered=self.__onArrowColorTriggered)
+        self.__arrowColorActionGroup.setExclusive(True) # upgrade to PyQt5 5.14
 
         def color_icon(color):
             icon = QIcon()
@@ -1577,10 +1579,14 @@ class SchemeEditWidget(QWidget):
                  if link.source_node in selection and
                     link.sink_node in selection]
         nodedups = [copy_node(node) for node in selection]
-        allnames = {node.title for node in scheme.nodes + nodedups}
-        for nodedup in nodedups:
-            nodedup.title = uniquify(
-                nodedup.title, allnames, pattern="{item} ({_})", start=1)
+
+        change_title = QSettings().value("oasys/change_title_on_duplicate", 0, int)
+
+        if change_title == 1:
+            allnames = {node.title for node in scheme.nodes + nodedups}
+            for nodedup in nodedups:
+                nodedup.title = uniquify(
+                    nodedup.title, allnames, pattern="{item} ({_})", start=1)
 
         node_to_dup = dict(zip(selection, nodedups))
 
